==> epubcheck_3.0.1.orig.tar.gz: epubcheck-3.0.1/src/main/java/com/adobe/epubcheck/util/OPSType.java <==
/*
 * Copyright (c) 2011 Adobe Systems Incorporated
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy of
 *  this software and associated documentation files (the "Software"), to deal in
 *  the Software without restriction, including without limitation the rights to
 *  use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 *  the Software, and to permit persons to whom the Software is furnished to do so,
 *  subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 *  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 *  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 *  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 *  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */

package com.adobe.epubcheck.util;

public class OPSType {
	private EPUBVersion version;
	private String mimeType;

	public OPSType(String mimeType, EPUBVersion version) {
		if (mimeType == null)
			mimeType = "";
		this.mimeType = mimeType;
		this.version = version;
	}

	public boolean equals(Object obj) {
		if (!(obj instanceof OPSType))
			return false;

		OPSType Obj = (OPSType) obj;

		return this.version == Obj.version
				&& this.mimeType.equals(Obj.mimeType);
	}

	public int hashCode() {
		return (int) (mimeType.hashCode() * version.ordinal());
	}
}

==> epubcheck_4.0.1.orig.tar.gz: epubcheck-4.0.1/src/main/java/com/adobe/epubcheck/util/OPSType.java <==
/*
 * Copyright (c) 2011 Adobe Systems Incorporated
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy of
 *  this software and associated documentation files (the "Software"), to deal in
 *  the Software without restriction, including without limitation the rights to
 *  use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 *  the Software, and to permit persons to whom the Software is furnished to do so,
 *  subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 *  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 *  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 *  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 *  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */

package com.adobe.epubcheck.util;

public class OPSType
{
  private final EPUBVersion version;
  private final String mimeType;

  public OPSType(String mimeType, EPUBVersion version)
  {
    if (mimeType == null)
    {
      mimeType = "";
    }
    this.mimeType = mimeType;
    this.version = version;
  }

  public boolean equals(Object obj)
  {
    if (!(obj instanceof OPSType))
    {
      return false;
    }

    OPSType Obj = (OPSType) obj;

    return this.version == Obj.version
        && this.mimeType.equals(Obj.mimeType);
  }

  public int hashCode()
  {
    return (mimeType.hashCode() * version.ordinal());
  }
}
